pub enum Ty {
Primitive(Primitive),
Struct(Struct),
Enum(Enum),
Tuple(Vec<Ty>),
Array(Vec<Ty>),
ByteArray(String),
FixedSizeArray((Vec<Ty>, u32)),
}Expand description
Represents all possible types in Cairo
Variants
Primitive(Primitive)
Struct(Struct)
Enum(Enum)
Tuple(Vec<Ty>)
Array(Vec<Ty>)
ByteArray(String)
FixedSizeArray((Vec<Ty>, u32))
Implementations
Sourceimpl Ty
impl Ty
pub fn name(&self) -> String
pub fn iter(&self) -> TyIter<'_> ⓘ
Sourcepub fn as_primitive(&self) -> Option<&Primitive>
pub fn as_primitive(&self) -> Option<&Primitive>
If the Ty is a primitive, returns the associated Primitive. Returns None
otherwise.
Sourcepub fn as_struct(&self) -> Option<&Struct>
pub fn as_struct(&self) -> Option<&Struct>
If the Ty is a struct, returns the associated Struct. Returns None otherwise.
Sourcepub fn as_enum(&self) -> Option<&Enum>
pub fn as_enum(&self) -> Option<&Enum>
If the Ty is an enum, returns the associated Enum. Returns None otherwise.
Sourcepub fn as_tuple(&self) -> Option<&Vec<Ty>>
pub fn as_tuple(&self) -> Option<&Vec<Ty>>
If the Ty is a tuple, returns the associated Vec<Ty>. Returns None otherwise.
Sourcepub fn as_array(&self) -> Option<&Vec<Ty>>
pub fn as_array(&self) -> Option<&Vec<Ty>>
If the Ty is an array, returns the associated Vec<Ty>. Returns None otherwise.
Sourcepub fn as_fixed_size_array(&self) -> Option<&(Vec<Ty>, u32)>
pub fn as_fixed_size_array(&self) -> Option<&(Vec<Ty>, u32)>
If the Ty is a fixed size array, returns the associated Vec<Ty>. Returns None
otherwise.
Sourcepub fn as_byte_array(&self) -> Option<&String>
pub fn as_byte_array(&self) -> Option<&String>
If the Ty is a byte array, returns the associated String. Returns None otherwise.
pub fn serialize(&self) -> Result<Vec<Felt>, PrimitiveError>
pub fn deserialize( &mut self, felts: &mut Vec<Felt>, legacy_storage: bool, ) -> Result<(), PrimitiveError>
Sourcepub fn diff(&self, other: &Ty) -> Option<Ty>
pub fn diff(&self, other: &Ty) -> Option<Ty>
Returns a new Ty containing only the differences between self and other
Sourcepub fn to_json_value(&self) -> Result<JsonValue, PrimitiveError>
pub fn to_json_value(&self) -> Result<JsonValue, PrimitiveError>
Convert a Ty to a JSON Value
Sourcepub fn from_json_value(
&mut self,
value: JsonValue,
) -> Result<(), PrimitiveError>
pub fn from_json_value( &mut self, value: JsonValue, ) -> Result<(), PrimitiveError>
Parse a JSON Value into a Ty