pub enum Primitive {
Show 16 variants
I8(Option<i8>),
I16(Option<i16>),
I32(Option<i32>),
I64(Option<i64>),
I128(Option<i128>),
U8(Option<u8>),
U16(Option<u16>),
U32(Option<u32>),
U64(Option<u64>),
U128(Option<u128>),
U256(Option<U256>),
Bool(Option<bool>),
Felt252(Option<Felt>),
ClassHash(Option<Felt>),
ContractAddress(Option<Felt>),
EthAddress(Option<Felt>),
}Variants
I8(Option<i8>)
I16(Option<i16>)
I32(Option<i32>)
I64(Option<i64>)
I128(Option<i128>)
U8(Option<u8>)
U16(Option<u16>)
U32(Option<u32>)
U64(Option<u64>)
U128(Option<u128>)
U256(Option<U256>)
Bool(Option<bool>)
Felt252(Option<Felt>)
ClassHash(Option<Felt>)
ContractAddress(Option<Felt>)
EthAddress(Option<Felt>)
Implementations
Sourceimpl Primitive
impl Primitive
Sourcepub fn as_i8(&self) -> Option<i8>
pub fn as_i8(&self) -> Option<i8>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_i16(&self) -> Option<i16>
pub fn as_i16(&self) -> Option<i16>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_i32(&self) -> Option<i32>
pub fn as_i32(&self) -> Option<i32>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_i64(&self) -> Option<i64>
pub fn as_i64(&self) -> Option<i64>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_i128(&self) -> Option<i128>
pub fn as_i128(&self) -> Option<i128>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u8(&self) -> Option<u8>
pub fn as_u8(&self) -> Option<u8>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u16(&self) -> Option<u16>
pub fn as_u16(&self) -> Option<u16>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u32(&self) -> Option<u32>
pub fn as_u32(&self) -> Option<u32>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u64(&self) -> Option<u64>
pub fn as_u64(&self) -> Option<u64>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u128(&self) -> Option<u128>
pub fn as_u128(&self) -> Option<u128>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_u256(&self) -> Option<U256>
pub fn as_u256(&self) -> Option<U256>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_felt252(&self) -> Option<Felt>
pub fn as_felt252(&self) -> Option<Felt>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_class_hash(&self) -> Option<Felt>
pub fn as_class_hash(&self) -> Option<Felt>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_contract_address(&self) -> Option<Felt>
pub fn as_contract_address(&self) -> Option<Felt>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn as_eth_address(&self) -> Option<Felt>
pub fn as_eth_address(&self) -> Option<Felt>
If the Primitive is variant type, returns the associated vartiant value. Returns
None otherwise.
Sourcepub fn set_i8(&mut self, value: Option<i8>) -> Result<(), PrimitiveError>
pub fn set_i8(&mut self, value: Option<i8>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_i16(&mut self, value: Option<i16>) -> Result<(), PrimitiveError>
pub fn set_i16(&mut self, value: Option<i16>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_i32(&mut self, value: Option<i32>) -> Result<(), PrimitiveError>
pub fn set_i32(&mut self, value: Option<i32>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_i64(&mut self, value: Option<i64>) -> Result<(), PrimitiveError>
pub fn set_i64(&mut self, value: Option<i64>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_i128(&mut self, value: Option<i128>) -> Result<(), PrimitiveError>
pub fn set_i128(&mut self, value: Option<i128>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u8(&mut self, value: Option<u8>) -> Result<(), PrimitiveError>
pub fn set_u8(&mut self, value: Option<u8>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u16(&mut self, value: Option<u16>) -> Result<(), PrimitiveError>
pub fn set_u16(&mut self, value: Option<u16>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u32(&mut self, value: Option<u32>) -> Result<(), PrimitiveError>
pub fn set_u32(&mut self, value: Option<u32>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u64(&mut self, value: Option<u64>) -> Result<(), PrimitiveError>
pub fn set_u64(&mut self, value: Option<u64>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u128(&mut self, value: Option<u128>) -> Result<(), PrimitiveError>
pub fn set_u128(&mut self, value: Option<u128>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_u256(&mut self, value: Option<U256>) -> Result<(), PrimitiveError>
pub fn set_u256(&mut self, value: Option<U256>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_bool(&mut self, value: Option<bool>) -> Result<(), PrimitiveError>
pub fn set_bool(&mut self, value: Option<bool>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_felt252(&mut self, value: Option<Felt>) -> Result<(), PrimitiveError>
pub fn set_felt252(&mut self, value: Option<Felt>) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_class_hash(
&mut self,
value: Option<Felt>,
) -> Result<(), PrimitiveError>
pub fn set_class_hash( &mut self, value: Option<Felt>, ) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_contract_address(
&mut self,
value: Option<Felt>,
) -> Result<(), PrimitiveError>
pub fn set_contract_address( &mut self, value: Option<Felt>, ) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
Sourcepub fn set_eth_address(
&mut self,
value: Option<Felt>,
) -> Result<(), PrimitiveError>
pub fn set_eth_address( &mut self, value: Option<Felt>, ) -> Result<(), PrimitiveError>
Sets the inner value of the Primitive enum if variant matches.
pub fn to_numeric(&self) -> usize
pub fn from_numeric(value: usize) -> Option<Self>
pub fn to_sql_type(&self) -> SqlType
pub fn to_sql_value(&self) -> String
pub fn from_sql_value(&mut self, value: &str) -> Result<(), PrimitiveError>
Sourcepub fn to_json_value(&self) -> Result<JsonValue, PrimitiveError>
pub fn to_json_value(&self) -> Result<JsonValue, PrimitiveError>
Convert to JSON Value with proper type representation
Sourcepub fn from_json_value(
&mut self,
value: JsonValue,
) -> Result<(), PrimitiveError>
pub fn from_json_value( &mut self, value: JsonValue, ) -> Result<(), PrimitiveError>
Parse from JSON Value with proper type validation
pub fn deserialize( &mut self, felts: &mut Vec<Felt>, ) -> Result<(), PrimitiveError>
pub fn serialize(&self) -> Result<Vec<Felt>, PrimitiveError>